@@ -1,3 +1,5 @@
+from copy import deepcopy
+
 from .base import BaseCsv, CsvForRead, ModelCsvForRead, BasePart
 from .metaclasses import CsvMetaclass, ModelCsvMetaclass
 
@@ -10,10 +12,11 @@ class ModelCsv(BaseCsv, metaclass=ModelCsvMetaclass):
     read_class = ModelCsvForRead
 
     @classmethod
-    def as_part(cls, field_name: str,
+    def as_part(cls, related_name: str,
                 callback: str = 'get_or_create_object') -> BasePart:
-
+        _meta = deepcopy(cls._meta)
+        _meta.as_part = True
         return type(
             f'{cls.__name__}Part', (cls, BasePart),
-            {'_meta': cls._meta}
-        )(field_name=field_name, callback=callback)
+            {'_meta': _meta}
+        )(related_name=related_name, callback=callback)
